/////////////////////////////////////////////////////////////////////////////
// Name:        TMTiler.h
// Purpose:     Header file for TMTiler.cpp
// Author:      Matthew Patitz <mpatitz@yahoo.com>
// Modified by:
// Created:     Nov/2007
// Copyright:   (c) 2008, Matthew John Patitz
// Licence:     GPL
/////////////////////////////////////////////////////////////////////////////

#ifndef __AUTOTILES_H__
#define __AUTOTILES_H__

#include <string>
#include <vector>
#include <fstream>
#include <iostream>
#include "tiles.h"
#include "tm.h"


///////////////////////////////////////////////////////////////////////////////////////////////////
//  Turing Machine assumptions:
//    - tape is one-way infinite to the right
//    - the TM will begin in the start state with the tape head on the leftmost cell of the tape
//    - the tape alphabet is exactly the input alphabet plus the blank symbol '_'
//
//  Naming conventions:
//    - if a name is not explicitly set for a tile type, it will be automatically generated in
//      the following format:
//        <north label>|<east lable>|<south label>|<west label>
//
///////////////////////////////////////////////////////////////////////////////////////////////////



//  NOTE:  When adding to this list of reserved characters, make sure to add to the ReservedChars array too!
#define EMPTY       "."
#define COPYLEFT    "<"
#define COPYRIGHT   ">"
#define NAMEDELIMIT "|"
char* ReservedChars[] = {BLANK, EMPTY, COPYLEFT, COPYRIGHT, NAMEDELIMIT };

#define STATES_STR      "States:"
#define ALPHABET_STR    "Alphabet:"
#define START_STR       "Start state:"
#define HALTING_STR     "Halting state:"
#define TRANSITION_STR  "Transitions:"
#define SEED_STR        "Seed:"


class TMTileSet : public TileSet
{
public:
  TMTileSet(StateSet& states, Alphabet& alphabet, std::string startState);

  StateSet      m_states;
  Alphabet      m_alphabet;
  std::string   m_startState;
};

void PrintTemplate(const char* tmplFileName);

#endif //  __AUTOTILES_H__
